@@ -3,7 +3,7 @@
  * This file is part of libaccounts-qt
  *
  * Copyright (C) 2009-2011 Nokia Corporation.
- * Copyright (C) 2015 Canonical Ltd.
+ * Copyright (C) 2015-2016 Canonical Ltd.
  *
  * Contact: Alberto Mardegan <alberto.mardegan@canonical.com>
  *
@@ -99,6 +99,7 @@ private Q_SLOTS:
     void testServiceType();
     void testUpdateAccount();
     void testApplication();
+    void testApplicationListServices();
 
 public Q_SLOTS:
     void onAccountServiceChanged();
@@ -321,6 +322,7 @@ void AccountsTest::testService()
     Service service = mgr->service(MYSERVICE);
     QVERIFY(service.isValid());
     QCOMPARE(service.name(), MYSERVICE);
+    QCOMPARE(service.description(), QStringLiteral("Test description"));
     QCOMPARE(service.iconName(), QString("general_myservice"));
     QCOMPARE(service.trCatalog(), QString("accounts"));
     QStringList tags;
@@ -1333,6 +1335,7 @@ void AccountsTest::testServiceType()
     QVERIFY(serviceType.isValid());
 
     QCOMPARE(serviceType.name(), EMAIL_SERVICE_TYPE);
+    QCOMPARE(serviceType.description(), QStringLiteral("Email test description"));
     QCOMPARE(serviceType.displayName(), QStringLiteral("Electronic mail"));
     QCOMPARE(serviceType.trCatalog(), QStringLiteral("translation_file"));
     QCOMPARE(serviceType.iconName(), QStringLiteral("email_icon"));
@@ -1418,6 +1421,7 @@ void AccountsTest::testApplication()
     QCOMPARE(application.iconName(), UTF8("mailer-icon"));
     QCOMPARE(application.desktopFilePath(),
              UTF8(qgetenv("AG_APPLICATIONS") + "/applications/mailer.desktop"));
+    QVERIFY(application.supportsService(email));
     QCOMPARE(application.serviceUsage(email),
              UTF8("Mailer can retrieve your e-mails"));
 
@@ -1430,6 +1434,7 @@ void AccountsTest::testApplication()
     application = apps[0];
     QCOMPARE(application.name(), UTF8("Gallery"));
     QCOMPARE(application.description(), UTF8("Image gallery"));
+    QVERIFY(application.supportsService(sharing));
     QCOMPARE(application.serviceUsage(sharing),
              UTF8("Publish images on OtherService"));
 
@@ -1442,5 +1447,23 @@ void AccountsTest::testApplication()
     delete manager;
 }
 
+void AccountsTest::testApplicationListServices()
+{
+    Manager *manager = new Manager();
+    QVERIFY(manager != 0);
+
+    Application application = manager->application("Mailer");
+    QVERIFY(application.isValid());
+
+    ServiceList services = manager->serviceList(application);
+
+    QCOMPARE(services.count(), 1);
+    Service service = services.first();
+
+    QCOMPARE(service.name(), QString("MyService"));
+
+    delete manager;
+}
+
 QTEST_GUILESS_MAIN(AccountsTest)
 #include "tst_libaccounts.moc"
